Index: third_party/protobuf/javanano/src/test/java/com/google/protobuf/nano/unittest_import_nano.proto |
diff --git a/third_party/protobuf/src/google/protobuf/unittest_import_lite.proto b/third_party/protobuf/javanano/src/test/java/com/google/protobuf/nano/unittest_import_nano.proto |
similarity index 81% |
copy from third_party/protobuf/src/google/protobuf/unittest_import_lite.proto |
copy to third_party/protobuf/javanano/src/test/java/com/google/protobuf/nano/unittest_import_nano.proto |
index 81b117fe8489ecc4cba5410dbf876b4ca473657b..1a3ddc57ea89854cd466655fa551c7b67b68a4c7 100644 |
--- a/third_party/protobuf/src/google/protobuf/unittest_import_lite.proto |
+++ b/third_party/protobuf/javanano/src/test/java/com/google/protobuf/nano/unittest_import_nano.proto |
@@ -1,6 +1,6 @@ |
// Protocol Buffers - Google's data interchange format |
// Copyright 2008 Google Inc. All rights reserved. |
-// http://code.google.com/p/protobuf/ |
+// https://developers.google.com/protocol-buffers/ |
// |
// Redistribution and use in source and binary forms, with or without |
// modification, are permitted provided that the following conditions are |
@@ -30,22 +30,19 @@ |
// Author: kenton@google.com (Kenton Varda) |
// |
// This is like unittest_import.proto but with optimize_for = LITE_RUNTIME. |
package protobuf_unittest_import; |
-option optimize_for = LITE_RUNTIME; |
+option java_package = "com.google.protobuf.nano.testimport"; |
+option java_outer_classname = "UnittestImportNano"; |
-option java_package = "com.google.protobuf"; |
- |
-import public "google/protobuf/unittest_import_public_lite.proto"; |
- |
-message ImportMessageLite { |
+message ImportMessageNano { |
optional int32 d = 1; |
} |
-enum ImportEnumLite { |
- IMPORT_LITE_FOO = 7; |
- IMPORT_LITE_BAR = 8; |
- IMPORT_LITE_BAZ = 9; |
+enum ImportEnumNano { |
+ IMPORT_NANO_FOO = 7; |
+ IMPORT_NANO_BAR = 8; |
+ IMPORT_NANO_BAZ = 9; |
} |
@@ -30,22 +30,19 @@ |
// Author: kenton@google.com (Kenton Varda) |
// |
-// This is like unittest_import.proto but with optimize_for = LITE_RUNTIME. |
+// This is like unittest_import.proto but with optimize_for = NANO_RUNTIME. |
package protobuf_unittest_import; |